#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oedepict

# @ <SNIPPET-IMAGE-SCALE>
image = oedepict.OEImage(100.0, 100.0)

image.DrawCircle(oedepict.OEGetCenter(image), 40.0, oedepict.OEBlackPen)
image.DrawText(oedepict.OEGetCenter(image), "circle", oedepict.OEDefaultFont)
oedepict.OEDrawBorder(image, oedepict.OELightGreyPen)

oedepict.OEWriteImage("image.png", image)

halfimage = oedepict.OEImage(image, 0.5)
oedepict.OEWriteImage("halfimage.png", halfimage)

doubleimage = oedepict.OEImage(image, 2.0)
oedepict.OEWriteImage("doubleimage.png", doubleimage)
# @ </SNIPPET-IMAGE-SCALE>

oedepict.OEWriteImage("image.pdf", image)
oedepict.OEWriteImage("halfimage.pdf", halfimage)
oedepict.OEWriteImage("doubleimage.pdf", doubleimage)
